#open data
t<-read.table("transects.txt",header=TRUE)
head(t)
d.count<-read.table("sponges_counts.txt",header=TRUE)
head(d.count)
m.size<-read.table("sponges_mean_size.txt",header=TRUE)
head(m.size)

#preliminary calculations

  #calculate transect surface
  t$S_transect=t$L_transect*t$W_transect
  head(t)
  
  #merge table count with table transect
  tcm<-merge(t,d.count,by="Transect_ID")
  head(tcm)

  #calculate corrected count value for sponges <25 in 2007 (estimated 45% missed)
  for (i in 1:length(tcm$Transect_ID)) {
    if(tcm$Year[i]==2007){
      tcm$N_inf_25_correct[i]=tcm$N_inf_25_cm2[i]/(1-0.45)
    }
    else{
      tcm$N_inf_25_correct[i]=tcm$N_inf_25_cm2[i]   
    }
  }
  
  #sponges counts (total on all transects for each year)
  tapply(tcm$N_inf_25_cm2,factor(tcm$Year),sum)->total_inf_25
  tapply(tcm$N_inf_25_correct,factor(tcm$Year),sum)->total_inf_25_correct
  tapply(tcm$N_25_50_cm2,factor(tcm$Year),sum)->total_25_50
  tapply(tcm$N_50_100_cm2,factor(tcm$Year),sum)->total_50_100
  tapply(tcm$N_100_200_cm2,factor(tcm$Year),sum)->total_100_200
  tapply(tcm$N_200_400_cm2,factor(tcm$Year),sum)->total_200_400
  tapply(tcm$N_sup_400_cm2,factor(tcm$Year),sum)->total_sup_400
  cbind(total_inf_25,total_inf_25_correct,total_25_50,total_50_100,total_100_200,total_200_400,total_sup_400)

  #calculate abundances for all size categories for each transect
  tcm$A_inf_25=tcm$N_inf_25_cm2/tcm$S_transect
  tcm$A_inf_25_correct=tcm$N_inf_25_correct/tcm$S_transect
  tcm$A_25_50=tcm$N_25_50_cm2/tcm$S_transect
  tcm$A_50_100=tcm$N_50_100_cm2/tcm$S_transect
  tcm$A_100_200=tcm$N_100_200_cm2/tcm$S_transect
  tcm$A_200_400=tcm$N_200_400_cm2/tcm$S_transect
  tcm$A_sup_400=tcm$N_sup_400_cm2/tcm$S_transect
  head(tcm)

  #more grouping
  tcm$N_sup_100=tcm$N_100_200_cm2+tcm$N_200_400_cm2+tcm$N_sup_400_cm2
  tcm$N_sup_50=tcm$N_50_100_cm2+tcm$N_100_200_cm2+tcm$N_200_400_cm2+tcm$N_sup_400_cm2
  tcm$N_sup_25=tcm$N_25_50+tcm$N_50_100_cm2+tcm$N_100_200_cm2+tcm$N_200_400_cm2+tcm$N_sup_400_cm2
  tcm$N_all=tcm$N_inf_25_correct+tcm$N_25_50+tcm$N_50_100_cm2+tcm$N_100_200_cm2+tcm$N_200_400_cm2+tcm$N_sup_400_cm2

  tcm$A_sup_100=tcm$N_sup_100/tcm$S_transect
  tcm$A_sup_50= tcm$N_sup_50/tcm$S_transect
  tcm$A_sup_25= tcm$N_sup_25/tcm$S_transect
  tcm$A_all= tcm$N_all/tcm$S_transect

  #calculate mean abundances for all size categories for each year
  tapply(tcm$A_inf_25_correct,factor(tcm$Year),mean)->mean_A_inf_25_correct
  tapply(tcm$A_25_50,factor(tcm$Year),mean)->mean_A_25_50
  tapply(tcm$A_50_100,factor(tcm$Year),mean)->mean_A_50_100
  tapply(tcm$A_sup_100,factor(tcm$Year),mean)->mean_A_sup_100
  cbind(mean_A_inf_25_correct,mean_A_25_50,mean_A_50_100,mean_A_sup_100)->Sponges_mean_A

  #Merge table tcm with table m.size
  siz.ab<-merge(tcm,m.size,by="Transect_ID")
  head(siz.ab)


#create data selection for 2007 and 2011

  #filter years
  tcm$Year==2007->s.2007
  tcm$Year==2011->s.2011
  
  #create subsets for years
  tcm[s.2007,]->d.2007
  tcm[s.2011,]->d.2011


#plots

  #information for axis scaling
    #maximum abundances
    tapply(tcm$A_all,factor(tcm$Year),max)
    tapply(tcm$A_inf_25_correct,factor(tcm$Year),max)
    tapply(tcm$A_25_50,factor(tcm$Year),max)
    tapply(tcm$A_50_100,factor(tcm$Year),max)
    
    #totalsurface
    tapply(tcm$S_transect,factor(tcm$Year),sum)

  #barplots: sponges abundances along the transects during both dives
  par(mfrow=c(5,2))
    #all
    barplot (d.2007$A_all, width=d.2007$S_transect,names.arg =d.2007$transect_id,main="2007 all",ylab= "indiv/m^2",ylim=c(0,6),xlim=c(0,1100),col=4,las=2)
    barplot (d.2011$A_all, width=d.2011$S_transect,names.arg =d.2011$transect_id,main="2011 all",ylab= "indiv/m^2",ylim=c(0,6),xlim=c(0,1100),col=3)
    #inf 25 corrected
    barplot (d.2007$A_inf_25_correct, width=d.2007$S_transect,names.arg =d.2007$transect_id,main="2007 <25_corrected",ylab= "indiv/m^2",ylim=c(0,6),xlim=c(0,1100),col=4,las=2)
    barplot (d.2011$A_inf_25_correct, width=d.2011$S_transect,names.arg =d.2011$transect_id,main="2011 <25_corrected",ylab= "indiv/m^2",ylim=c(0,6),xlim=c(0,1100),col=3)
    #25-50
    barplot (d.2007$A_25_50, width=d.2007$S_transect,names.arg =d.2007$transect_id,main="2007 25-50cm^2",ylab= "indiv/m^2",ylim=c(0,1),xlim=c(0,1100),col=4,las=2)
    barplot (d.2011$A_25_50, width=d.2011$S_transect,names.arg =d.2011$transect_id,main="2011 25-50cm^2",ylab= "indiv/m^2",ylim=c(0,1),xlim=c(0,1100),col=3)
    #50-100
    barplot (d.2007$A_50_100, width=d.2007$S_transect,names.arg =d.2007$transect_id,main="2007 50-100cm^2",ylab= "indiv/m^2",ylim=c(0,1),xlim=c(0,1100),col=4)
    barplot (d.2011$A_50_100, width=d.2011$S_transect,names.arg =d.2011$transect_id,main="2011 50-100cm^2",ylab= "indiv/m^2",ylim=c(0,1),xlim=c(0,1100),col=3)
    #sup 100
    barplot (d.2007$A_sup_100, width=d.2007$S_transect,names.arg =d.2007$transect_id,main="2007 >100cm^2",ylab= "indiv/m^2",ylim=c(0,1),xlim=c(0,1100),col=4)
    barplot (d.2011$A_sup_100, width=d.2011$S_transect,names.arg =d.2011$transect_id,main="2011 >100cm^2",ylab= "indiv/m^2",ylim=c(0,1),xlim=c(0,1100),col=3)

  #boxplots: distribution of sponges abundances during both dives
  par(mfrow=c(2,4))
  boxplot(A_inf_25_correct~Year,data=tcm,name=tcm$Year,main="<25cm^2 corrected*")
  boxplot(A_25_50~Year,data=tcm,name=tcm$Year,main="25-50cm^2")
  boxplot(A_50_100~Year,data=tcm,name=tcm$Year,main="50-100cm^2*")
  boxplot(A_sup_100~Year,data=tcm,name=tcm$Year,main=">100cm^2*")
  boxplot(A_all~Year,data=tcm,name=tcm$Year,main="All*")
  boxplot(A_sup_25~Year,data=tcm,name=tcm$Year,main=">25cm^2*")
  boxplot(A_sup_50~Year,data=tcm,name=tcm$Year,main=">50cm^2*")
  boxplot(A_inf_25~Year,data=tcm,name=tcm$Year,main="<25cm^2*")

  #barplot: mean abundances per size class during both dives
  par(mfrow=c(1,1),cex=1)
  colors<-c("cornflowerblue","darkolivegreen3")
  groupnames<-c("<25","25-50","50-100",">100")
  leg.text<-c("2007","2011")
  barplot(Sponges_mean_A,beside=TRUE,ylab= "Sponges per square meter",ylim=c(0,1),xlab="Size class [cm^2]",names.arg=groupnames,col=colors)
  legend("topright",leg.text,cex=1,fill=colors)

  #barplot: abundance % increase between both dives
  par(mfrow=c(1,1),cex=1)
  Sponges_mean_A[1,]->ab.2007
  Sponges_mean_A[2,]->ab.2011
  100*(ab.2011-ab.2007)/ab.2007->Increase
  barplot(Increase,ylab= "% Increase",ylim=c(0,200),xlab="Size class [cm^2]",names.arg=groupnames,col="red3")


#tests: changes in abundances between the 2 transects

#functions for standard error
  std <- function(x) sd(x)/sqrt(length(x))#fits better to definition bu same results

  #<25 (underestimated in 2007!!!)
    
    #wilcoxon test (no normal distribution, non-parametric test)
      tapply(tcm$A_inf_25,factor(tcm$Year),mean)# 2007:0.2970985   2011:0.9051092 
      tapply(tcm$A_inf_25,factor(tcm$Year),std) # 2007:0.04841195   2011:0.10353495
      wilcox.test(d.2007$A_inf_25,d.2011$A_inf_25,alternative="less")#significant p=5.379e-09


  #<25 (with correction factor for 2007)

    #wilcoxon test (no normal distribution, non-parametric test)
      tapply(tcm$A_inf_25_correct,factor(tcm$Year),mean)# 2007:0.540179    2011:0.9051092 
      tapply(tcm$A_inf_25_correct,factor(tcm$Year),std)# 2007:0.08802172   2011:0.10353495
      wilcox.test(d.2007$A_inf_25_correct,d.2011$A_inf_25_correct,alternative="less")#significant p=0.0004574

      # permutation test (parameter test is p in Wilcoxon test):repeat for several permutations of the "year" factor
        cnt=0
        set.seed(124316)
        n.1=sum(tcm$Year=="2007")
        n.2=sum(tcm$Year=="2011")
        res.i25c=tcm$A_inf_25_correct
        for (i in 1:10000)
        {
          s1=sample(1:(n.1+n.2),n.1) 
          if (wilcox.test(res.i25c[s1],res.i25c[-s1],alternative="less")$p.value<0.05) cnt=cnt+1 #significant
        }
        cnt/10000 # 0.0496


  #25_50

    #wilcoxon test (no normal distribution, non-parametric test)
      tapply(tcm$A_25_50,factor(tcm$Year),mean)#2007:0.1497074 2011:0.1589697
      tapply(tcm$A_25_50,factor(tcm$Year),std)#2007:0.03200189 2011:0.01983775
      wilcox.test(d.2007$A_25_50,d.2011$A_25_50,alternative="less")#not significant p=0.2034 

      # permutation test (parameter test is p in Wilcoxon test):repeat for several permutations of the "year" factor
        cnt=0
        set.seed(124316)
        n.1=sum(tcm$Year=="2007")
        n.2=sum(tcm$Year=="2011")
        res.2550=tcm$A_25_50
        for (i in 1:10000)
        {
          s1=sample(1:(n.1+n.2),n.1) 
          if (wilcox.test(res.2550[s1],res.2550[-s1],alternative="less")$p.value<0.05) cnt=cnt+1 #significant
        }
        cnt/10000 # 0.0491
    
  
  #50_100

    #wilcoxon test (no normal distribution, non-parametric test)
      tapply(tcm$A_50_100,factor(tcm$Year),mean)#2007:0.04453696 2011:0.13223614
      tapply(tcm$A_50_100,factor(tcm$Year),std)#2007:0.01064243  2011:0.01589571
      wilcox.test(d.2007$A_50_100,d.2011$A_50_100,alternative="less")#significant p=4.021e-06
  
      # permutation test (parameter test is p in Wilcoxon test):repeat for several permutations of the "year" factor
        cnt=0
        set.seed(124316)
        n.1=sum(tcm$Year=="2007")
        n.2=sum(tcm$Year=="2011")
        res.50100=tcm$A_50_100
        for (i in 1:10000)
        {
          s1=sample(1:(n.1+n.2),n.1) 
          if (wilcox.test(res.50100[s1],res.50100[-s1],alternative="less")$p.value<0.05) cnt=cnt+1 #significant
        }
        cnt/10000# 0.0479

  
  #>100

    #wilcoxon test (no normal distribution, non-parametric test)
      tapply(tcm$A_sup_100,factor(tcm$Year),mean)#2007:0.05790635 2011:0.11151598 
      tapply(tcm$A_sup_100,factor(tcm$Year),std)#2007:0.01174861 2011:0.01446349
      wilcox.test(d.2007$A_sup_100,d.2011$A_sup_100,alternative="less")#significant p=0.007397

      # permutation test (parameter test is p in Wilcoxon test):repeat for several permutations of the "year" factor
        cnt=0
        set.seed(124316)
        n.1=sum(tcm$Year=="2007")
        n.2=sum(tcm$Year=="2011")
        res.s100=tcm$A_sup_100
        for (i in 1:10000)
        {
          s1=sample(1:(n.1+n.2),n.1) 
          if (wilcox.test(res.s100[s1],res.s100[-s1],alternative="less")$p.value<0.05) cnt=cnt+1 #significant
        }
        cnt/10000# 0.0492


  #all

    #wilcoxon test (no normal distribution, non-parametric test)
      tapply(tcm$A_all,factor(tcm$Year),mean)#2007:0.7923299  2011:1.3078310  
      tapply(tcm$A_all,factor(tcm$Year),std)#2007:0.1132431  2011:0.1241510
      wilcox.test(d.2007$A_all,d.2011$A_all,alternative="less")#significant p=0.0001127
      
      # permutation test (parameter test is p in Wilcoxon test):repeat for several permutations of the "year" factor
        cnt=0
        set.seed(124316)
        n.1=sum(tcm$Year=="2007")
        n.2=sum(tcm$Year=="2011")
        res.all=tcm$A_all
        for (i in 1:10000)
        {
          s1=sample(1:(n.1+n.2),n.1) 
          if (wilcox.test(res.all[s1],res.all[-s1],alternative="less")$p.value<0.05) cnt=cnt+1 #significant
        }
        cnt/10000# 0.0497   

