#open data
t<-read.table("transects.txt",header=TRUE)
head(t)
a.count<-read.table("asteroids.txt",header=TRUE)
head(a.count)


#preliminary calculations

  #calculate transect surface
  t$S_transect=t$L_transect*t$W_transect
  head(t)
  
  #merge table count with table transect
  tp<-merge(t,a.count,by="Transect_ID")
  head(tp)


#asteroids abundances
tp$A_aster_sup_5cm=tp$N_aster_sup_5cm/tp$S_transect
tp$A_aster_inf_5cm=tp$N_aster_inf_5cm/tp$S_transect
tp$A_O_meridionalis=tp$N_O_meridionalis/tp$S_transect
head(tp)


#create data selection for 2007 and 2011
  
  #filter years
  tp$Year==2007->s.2007
  tp$Year==2011->s.2011
  
  #create subsets for years
  tp[s.2007,]->d.2007
  tp[s.2011,]->d.2011


#plots

  #barplots: asteroids abundances along the transects during both dives
  par(mfrow=c(3,2))
  
  # all asteroids >5cm
  barplot (d.2007$A_aster_sup_5cm, width=d.2007$S_transect,names.arg =d.2007$transect_id,main="Asteroids >5cm",ylab= "indiv/m^2",ylim=c(0,0.5),xlim=c(0,1100),col=4,las=2)
  barplot (d.2011$A_aster_sup_5cm, width=d.2011$S_transect,names.arg =d.2011$transect_id,main="Asteroids >5cm",ylab= "indiv/m^2",ylim=c(0,0.5),xlim=c(0,1100),col=3)

  # asteroids <5cm
  barplot (d.2007$A_aster_inf_5cm, width=d.2007$S_transect,names.arg =d.2007$transect_id,main="Asteroids <5cm",ylab= "indiv/m^2",ylim=c(0,0.5),xlim=c(0,1100),col=4,las=2)
  barplot (d.2011$A_aster_inf_5cm, width=d.2011$S_transect,names.arg =d.2011$transect_id,main="Asteroids <5cm",ylab= "indiv/m^2",ylim=c(0,0.5),xlim=c(0,1100),col=3)

  # Odontaster meridonalis (>5cm)
  barplot (d.2007$A_O_meridionalis, width=d.2007$S_transect,names.arg =d.2007$transect_id,main="Odontaster meridonalis >5cm",ylab= "indiv/m^2",ylim=c(0,0.5),xlim=c(0,1100),col=4,las=2)
  barplot (d.2011$A_O_meridionalis, width=d.2011$S_transect,names.arg =d.2011$transect_id,main="Odontaster meridonalis >5cm",ylab= "indiv/m^2",ylim=c(0,0.5),xlim=c(0,1100),col=3)
  
  # boxplots: distribution of asteroids abundances during both dives
  par(mfrow=c(1,3))
  boxplot(A_aster_sup_5cm~Year,data=tp,name=tp$Year.x,main="Asteroids >5cm")
  boxplot(A_aster_inf_5cm~Year,data=tp,name=tp$Year.x,main="Asteroids <5cm")
  boxplot(A_O_meridionalis~Year,data=tp,name=tp$Year.x,main="Odontaster meridonalis >5cm")


#tests: changes in asteroids abundances between the 2 transects

  #functions for standard error
    stderr <- function(x) sqrt(var(x)/length(x))  
    std <- function(x) sd(x)/sqrt(length(x))#fits better to definition but same results

  # all asteroids >5cm
    #wilcoxon test (no normal distribution, non-parametric test)
    tapply(tp$A_aster_sup_5cm,factor(tp$Year),mean)# 2007:0.01311258   2011:0.02210753 
    tapply(tp$A_aster_sup_5cm,factor(tp$Year),sd) # 2007:0.03726626   2011:0.04244149
    tapply(tp$A_aster_sup_5cm,factor(tp$Year),std) # 2007:0.005435843   2011:0.005036879 
    wilcox.test(d.2007$A_aster_sup_5cm,d.2011$A_aster_sup_5cm,alternative="less")#not significant p=0.07378

  # asteroids <5cm
    #wilcoxon test (no normal distribution, non-parametric test)
    tapply(tp$A_aster_inf_5cm,factor(tp$Year),mean)# 2007:0.005464294   2011:0.035133588 
    tapply(tp$A_aster_inf_5cm,factor(tp$Year),sd) # 2007:0.03746131  2011:0.07264301  
    tapply(tp$A_aster_inf_5cm,factor(tp$Year),std) # 2007:0.005464294   2011:0.008621140 
    wilcox.test(d.2007$A_aster_inf_5cm,d.2011$A_aster_inf_5cm,alternative="less")# significant p=5.629e-05

  # Odontaster meridonalis (>5cm)  
    #wilcoxon test (no normal distribution, non-parametric test)
    tapply(tp$A_O_meridionalis,factor(tp$Year),mean)# 2007:0.008569502   2011:0.009415587
    tapply(tp$A_O_meridionalis,factor(tp$Year),sd) # 2007:0.02232200   2011:0.02658022
    tapply(tp$A_O_meridionalis,factor(tp$Year),std) # 2007:0.003255998   2011:0.003154492
    wilcox.test(d.2007$A_O_meridionalis,d.2011$A_O_meridionalis,alternative="less")# not significant p=0.5949

#proportion of "juveniles"

tapply(tp$N_aster_sup_5cm,factor(tp$Year),sum)->N_adults
tapply(tp$N_aster_inf_5cm,factor(tp$Year),sum)->N_juvenile
N_adults
N_juvenile
N_juvenile/(N_juvenile+N_adults)
