#open sponges size
size<-read.table("sponge_size.txt",header=TRUE)
head(size)


#preliminary calculations

  #calculate sponges real size (sponge real size = sponge measured size*laser real size/laser measured size)
  for (i in 1:length(size$Transect_ID)) {
    if(size$Sponge_Hmeas_cm[i]>0){
      size$Sponge_Hreal_cm[i]=(size$Sponge_Hmeas_cm*size$laser_real_cm)[i]/size$laser_meas_cm[i]
      size$Sponge_Wreal_cm[i]=(size$Sponge_Wmeas_cm*size$laser_real_cm)[i]/size$laser_meas_cm[i]
    }
    else{
      size$Sponge_Hreal_cm[i]=0
      size$Sponge_Wreal_cm[i]=0   
    }
  }
  
  #calculate sponges surfaces (S=H*W)
  size$Sponges_S_cm2=size$Sponge_Hreal_cm*size$Sponge_Wreal_cm
  
  
  #calculate sponges dry mass (equations obtained from size_mass script)(if not AJ then considered as RV)
  unique(size$specie)
  
  for (i in 1:length(size$Transect_ID)) {
    if(size$specie[i]=='AJ'){
      size$dry_mass_g[i]=0.5299*size$Sponges_S_cm2[i] 
      }
    else{
      size$dry_mass_g[i]=0.7491*size$Sponges_S_cm2[i] 
      }
    }
  
  
  #calculate sponges ash free dry mass (AFDM)(equations obtained from size_mass script)(if not AJ then considered as RV)
  for (i in 1:length(size$Transect_ID)) {
    if(size$specie[i]=='AJ'){
      size$AFDM_g[i]=0.1629*size$Sponges_S_cm2[i] 
    }
    else{
      size$AFDM_g[i]=0.1489*size$Sponges_S_cm2[i] 
    }
  }
  head(size)

#output table
write.table(size,file="sponges_mass.txt")


#classify sponges in size classes (detect sponges sizes)
  #<25cm^2
  for (i in 1:length(size$Transect_ID)) {
    if((size$Sponges_S_cm2[i]<25) & (size$Sponges_S_cm2[i]<=25)){
      size$inf_25cm2[i]=1
    }
    else{
      size$inf_25cm2[i]=0
    }
  }

  
  #25-50cm^2
  for (i in 1:length(size$Transect_ID)) {
    if((size$Sponges_S_cm2[i]>25) & (size$Sponges_S_cm2[i]<=50)){
      size$b_25_50_cm2[i]=1
    }
    else{
      size$b_25_50_cm2[i]=0
    }
  }

  
  #50-100cm^2
  for (i in 1:length(size$Transect_ID)) {
    if((size$Sponges_S_cm2[i]>50) & (size$Sponges_S_cm2[i]<=100)){
      size$b_50_100_cm2[i]=1
    }
    else{
      size$b_50_100_cm2[i]=0
    }
  }

  
  #100-200cm^2
  for (i in 1:length(size$Transect_ID)) {
    if((size$Sponges_S_cm2[i]>100) & (size$Sponges_S_cm2[i]<=200)){
      size$b_100_200_cm2[i]=1
    }
    else{
      size$b_100_200_cm2[i]=0
    }
  }

  
  #200-400cm^2
  for (i in 1:length(size$Transect_ID)) {
    if((size$Sponges_S_cm2[i]>200) & (size$Sponges_S_cm2[i]<=400)){
      size$b_200_400_cm2[i]=1
    }
    else{
      size$b_200_400_cm2[i]=0
    }
  }

  
  # > 400cm^2
  for (i in 1:length(size$Transect_ID)) {
    if(size$Sponges_S_cm2[i]>400){
      size$sup_400_cm2[i]=1
    }
    else{
      size$sup_400_cm2[i]=0
    }
  }
  head(size)


#counts sponges in each size class for each transect
  unique(size$Transect_ID)->Transect_ID
  tapply(size$inf_25cm2,factor(size$Transect_ID),sum)->N_inf_25_cm2
  tapply(size$b_25_50_cm2,factor(size$Transect_ID),sum)->N_25_50_cm2
  tapply(size$b_50_100_cm2,factor(size$Transect_ID),sum)->N_50_100_cm2
  tapply(size$b_100_200_cm2,factor(size$Transect_ID),sum)->N_100_200_cm2
  tapply(size$b_200_400_cm2,factor(size$Transect_ID),sum)->N_200_400_cm2
  tapply(size$sup_400_cm2,factor(size$Transect_ID),sum)->N_sup_400_cm2
  cbind(N_inf_25_cm2,N_25_50_cm2,N_50_100_cm2,N_100_200_cm2,N_200_400_cm2,N_sup_400_cm2)->counts
  counts

#mean size per transect
  tapply(size$Sponges_S_cm2,factor(size$Transect_ID),mean)->Sponges_mean_S
  cbind(Sponges_mean_S)->mean_size

#output table
write.table(counts,file="sponges_counts.txt")# Manually add a "Transect_ID" header in the table (first column)
#output table
write.table(mean_size,file="sponges_mean_size.txt")# Manually add a "Transect_ID" header in the table (first column)









