#open sponges size
size<-read.table("sponge_size.txt",header=TRUE)
head(size)

#preliminary calculations

  #calculate sponges real size (sponge real size = sponge measured size*laser real size/laser measured size)
    for (i in 1:length(size$Transect_ID)) {
      if(size$Sponge_Hmeas_cm[i]>0){
        size$Sponge_Hreal_cm[i]=(size$Sponge_Hmeas_cm*size$laser_real_cm)[i]/size$laser_meas_cm[i]
        size$Sponge_Wreal_cm[i]=(size$Sponge_Wmeas_cm*size$laser_real_cm)[i]/size$laser_meas_cm[i]
      }
      else{
        size$Sponge_Hreal_cm[i]=0
        size$Sponge_Wreal_cm[i]=0   
      }
    }
    head(size)

  #calculate sponges surfaces (S=H*W)
    size$Sponges_S_cm2=size$Sponge_Hreal_cm*size$Sponge_Wreal_cm
    head(size)
  
# sponges size classes (detect sponges sizes)
    #<25cm^2
    for (i in 1:length(size$Transect_ID)) {
      if((size$Sponges_S_cm2[i]>0) & (size$Sponges_S_cm2[i]<=25)){
        size$inf_25cm2[i]=1
      }
      else{
        size$inf_25cm2[i]=0
      }
    }
    
    #25-50cm^2
    for (i in 1:length(size$Transect_ID)) {
      if((size$Sponges_S_cm2[i]>25) & (size$Sponges_S_cm2[i]<=50)){
        size$b_25_50_cm2[i]=1
      }
      else{
        size$b_25_50_cm2[i]=0
      }
    }
    
    #50-100cm^2
    for (i in 1:length(size$Transect_ID)) {
      if((size$Sponges_S_cm2[i]>50) & (size$Sponges_S_cm2[i]<=100)){
        size$b_50_100_cm2[i]=1
      }
      else{
        size$b_50_100_cm2[i]=0
      }
    }
    
    #>100
    for (i in 1:length(size$Transect_ID)) {
      if(size$Sponges_S_cm2[i]>100){
        size$sup_100[i]=1
      }
      else{
        size$sup_100[i]=0
      }
    }
    
    #all
    for (i in 1:length(size$Transect_ID)) {
      if(size$Sponges_S_cm2[i]>0){
        size$all[i]=1
      }
      else{
        size$all[i]=0
      }
    }
    
    #>25
    for (i in 1:length(size$Transect_ID)) {
      if(size$Sponges_S_cm2[i]>25){
        size$sup_25[i]=1
      }
      else{
        size$sup_25[i]=0
      }
    }
    
    head(size)
    
    
    #sum individuals per size class per year
    tapply(size$inf_25cm2,factor(size$Year),sum)->N_inf_25
    tapply(size$b_25_50_cm2,factor(size$Year),sum)->N_25_50
    tapply(size$b_50_100_cm2,factor(size$Year),sum)->N_50_100
    tapply(size$sup_100,factor(size$Year),sum)->N_sup_100
    tapply(size$sup_25,factor(size$Year),sum)->N_sup_25
    
    #correction for sponges <25 in 2007 (estimated 45% missed)
    N_inf_25->N_inf_25_correct
    N_inf_25_correct[1]=N_inf_25_correct[1]/(1-0.45)
    
    #total number of sponges for each year
    N_all=N_inf_25_correct+N_25_50+N_50_100+N_sup_100
    
    #calculate frequencies
    F_inf_25_correct=N_inf_25_correct/N_all
    F_25_50=N_25_50/N_all
    F_50_100=N_50_100/N_all
    F_sup_100=N_sup_100/N_all
    
    #combine data
    rbind(F_inf_25_correct,F_25_50,F_50_100,F_sup_100)->frequencies

#plot
par(mfrow=c(1,1))
groupnames<-c("<25 cm^2","25-50 cm^2","50-100 cm^2",">100 cm^2")
colors<-c("cornflowerblue","darkolivegreen3")
leg.text<-c("2007","2011")
barplot(t(frequencies), beside=TRUE,ylab= "Frequency",ylim=c(0,1),xlab="Size class",names.arg=groupnames,col=colors)
legend("topright",leg.text,cex=1.5,fill=colors)




