
#open Rossella cf. villosa (RV) and Anoxycalyx joubini (AJ) size mass files
smRV<-read.table("RV_size_mass.txt",header=TRUE)
smAJ<-read.table("AJ_size_mass.txt",header=TRUE)


#preliminary calculations

  #calculate sponges surfaces (S=H*W)
  smRV$sponge_S_cm2=smRV$sponge_H_cm*smRV$sponge_W_cm
  smAJ$sponge_S_cm2=smAJ$sponge_H_cm*smAJ$sponge_W_cm
  
  #calculate sponges ash free dry mass (organic dry mass)(AFDM=DM*organic ratio)
  smRV$AFDM_g=smRV$dry_mass_g*smRV$organic_ratio
  smAJ$AFDM_g=smAJ$dry_mass_g*smAJ$organic_ratio
  
  #calculate sponges ash dry mass (inorganic dry mass)(ADM=DM*inorganic ratio)
  smRV$ADM_g=smRV$dry_mass_g*smRV$inorganic_ratio
  smAJ$ADM_g=smAJ$dry_mass_g*smAJ$inorganic_ratio
  smRV
  smAJ

  #calculate mean inorganic ratios

    #Rossella cf. villosa
      mean(smRV$inorganic_ratio,na.rm=TRUE)#0.8066667
      sd(smRV$inorganic_ratio,na.rm=TRUE)#0.02397916

    #Anoxycalyx joubini
      mean(smAJ$inorganic_ratio,na.rm=TRUE)#0.6614286
      sd(smAJ$inorganic_ratio,na.rm=TRUE)#0.04298394


#regression

  par(mfrow=c(2,2))

  #surface-dry mass regression (we want to use the size to estimate the dry mass so we need to determine the equation that relates them)
  
    #Rossella cf. villosa (RV)
    plot(smRV$sponge_S_cm2,smRV$dry_mass_g,main="Rossella cf. villosa dry mass",xlab="Sponge surface [cm^2]",ylab="Sponge dry mass [g]")
    lm(dry_mass_g~0+sponge_S_cm2,data=smRV)->l.mod.RV.DM #intercept set to zero 
    l.mod.RV.DM # for RV: DM=0.7491*S
    abline(l.mod.RV.DM)
    summary(l.mod.RV.DM) # for RV: Adjusted R-squared= 0.9798
    
    #Anoxycalyx joubini (AJ)
    plot(smAJ$sponge_S_cm2,smAJ$dry_mass_g,main="Anoxycalyx (Scolymastra) joubini dry mass",xlab="Sponge surface [cm^2]",ylab="Sponge dry mass [g]")
    lm(dry_mass_g~0+sponge_S_cm2,data=smAJ)->l.mod.AJ.DM #intercept set to zero 
    l.mod.AJ.DM # for AJ: DM=0.5299*S
    abline(l.mod.AJ.DM)
    summary(l.mod.AJ.DM) # for AJ: Adjusted R-squared= 0.9933 


  #surface-ash free dry mass regression (we want to use the size to estimate the ash free dry mass so we need to determine the equation that relates them)

    #Rossella cf. villosa (RV)
    plot(smRV$sponge_S_cm2,smRV$AFDM_g,main="Rossella cf. villosa ash free dry mass",xlab="Sponge surface [cm^2]",ylab="Sponge ash free dry mass [g]")
    lm(AFDM_g~0+sponge_S_cm2,data=smRV)->l.mod.RV.AFDM #intercept set to zero 
    l.mod.RV.AFDM # for RV: AFDM=0.1489*S
    abline(l.mod.RV.AFDM)
    summary(l.mod.RV.AFDM) # for RV: Adjusted R-squared= 0.9471 
  
    #Anoxycalyx joubini (AJ)
    plot(smAJ$sponge_S_cm2,smAJ$AFDM_g,main="Anoxycalyx (Scolymastra) joubini ash free dry mass",xlab="Sponge surface [cm^2]",ylab="Sponge ash free dry mass [g]")
    lm(AFDM_g~0+sponge_S_cm2,data=smAJ)->l.mod.AJ.AFDM #intercept set to zero 
    l.mod.AJ.AFDM # for AJ: AFDM=0.1629*S
    abline(l.mod.AJ.AFDM)
    summary(l.mod.AJ.AFDM) # for AJ: Adjusted R-squared= 0.9787 


